Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6)

Unified Diff: chrome/browser/browsing_data_remover.h

Issue 10413072: Teaching BrowsingDataRemover how to delete application data. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Inadvertant include. Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/browsing_data_remover.h
diff --git a/chrome/browser/browsing_data_remover.h b/chrome/browser/browsing_data_remover.h
index c34db65ade7be003da2d66a253fe71e4e1292e1c..65faa59ca4e3a8fe55ced2a25d8b448234a78a98 100644
--- a/chrome/browser/browsing_data_remover.h
+++ b/chrome/browser/browsing_data_remover.h
@@ -120,7 +120,7 @@ class BrowsingDataRemover : public content::NotificationObserver,
base::Time delete_end);
// Removes the specified items related to browsing for all origins.
- void Remove(int remove_mask);
+ void Remove(int remove_mask, bool include_protected_origins);
void AddObserver(Observer* observer);
void RemoveObserver(Observer* observer);
@@ -180,11 +180,11 @@ class BrowsingDataRemover : public content::NotificationObserver,
// Removes the specified items related to browsing for a specific host. If the
// provided |origin| is empty, data is removed for all origins. If
// |remove_protected_origins| is true, then data is removed even if the origin
// is otherwise protected (e.g. as an installed application).
void RemoveImpl(int remove_mask,
const GURL& origin,
- bool remove_protected_origins);
+ bool include_protected_origins);
// If we're not waiting on anything, notifies observers and deletes this
// object.
@@ -316,7 +316,7 @@ class BrowsingDataRemover : public content::NotificationObserver,
GURL remove_origin_;
// Should data for protected origins be removed?
- bool remove_protected_;
+ bool include_protected_;
ObserverList<Observer> observer_list_;

Powered by Google App Engine
@@ -180,11 +180,11 @@ class BrowsingDataRemover : public content::NotificationObserver,
// Removes the specified items related to browsing for a specific host. If the
// provided |origin| is empty, data is removed for all origins. If
- // |remove_protected_origins| is true, then data is removed even if the origin
- // is otherwise protected (e.g. as an installed application).
+ // |include_protected_origins| is true, then data is removed even if the
+ // origin is otherwise protected (e.g. as an installed application).
void RemoveImpl(int remove_mask,
const GURL& origin,
This is Rietveld 408576698